==> patch-2.5.3.15.zip: app/templates/default/partials/createButton.php <==
<?php use Helpers\Url; use Helpers\Auth;?>
<?php if(Auth::checkCloudPermission('sync')){ ?>
<?php if(Auth::checkUserPermission('admin')) {?>
<?php if($data['createMiniCloud'] == 'true' || $data['fileUpload'] == 'true' || $data['createFolder'] == 'true') {?>
<div class="share pull-right">
    <button class="share-toggle-button universalCreate">
        <i class="createButton share-icon fa fa-plus"></i>
    </button>
    <?php if($data['createMiniCloud'] == 'true' || $data['fileUpload'] == 'true' || $data['createFolder'] == 'true') {?>
    <ul class="share-items">
        <?php if(Auth::checkUserPermission('admin')) {?>
            <?php if($data['createMiniCloud'] == 'true') { ?>
            <li title="Create a MiniCloud"  id="createAminicloud" class="share-item">
                <a href="" class="share-button" data-toggle="modal" data-target="#createMiniCloud">
                    <i class="share-icon fa fa-cloud"></i>
                </a>
            </li>
            <?php } ?>
        <?php } ?>
        <?php if($data['active'] == 'sync'){ ?>
            <?php if($data['fileUpload'] == 'true') { ?>
                <?php if(!isMobile()){ ?>
                <li title="New Upload" id="newUpload" class="share-item">
                    <a href="" class="share-button" data-toggle="modal" data-target="#uploadFilesNew">
                        <i class="share-icon fa fa-upload"></i>
                    </a>
                </li>
                <?php } ?>
            <?php } ?>
        <?php } ?>
        <?php if($data['createFolder'] == 'true') { ?>
        <li title="Create a Folder" id="createAFolder" class="share-item">
            <a href="" class="share-button" data-toggle="modal" data-target="#createFolder">
                <i class="share-icon fa fa-folder-open"></i>
            </a>
        </li>
        <?php } ?>
    </ul>
    <?php } ?>
</div>
<?php } ?>
<?php }else {?>
<?php if($data['fileUpload'] == 'true' || $data['createFolder'] == 'true') {?>
<div class="share pull-right">
    <button class="share-toggle-button universalCreate">
        <i class="createButton share-icon fa fa-plus"></i>
    </button>
    <?php if($data['fileUpload'] == 'true' || $data['createFolder'] == 'true') {?>
    <ul class="share-items">
        <?php if($data['active'] == 'sync'){ ?>
            <?php if($data['fileUpload'] == 'true') { ?>
                <?php if(!isMobile()){ ?>
                <li title="New Upload" id="newUpload" class="share-item">
                    <a href="" class="share-button" data-toggle="modal" data-target="#uploadFilesNew">
                        <i class="share-icon fa fa-upload"></i>
                    </a>
                </li>
                <?php } ?>
            <?php } ?>
        <?php } ?>
        <?php if($data['createFolder'] == 'true') { ?>
        <li title="Create a Folder" id="createAFolder" class="share-item">
            <a href="" class="share-button" data-toggle="modal" data-target="#createFolder">
                <i class="share-icon fa fa-folder-open"></i>
            </a>
        </li>
        <?php } ?>
    </ul>
    <?php } ?>
</div>
<?php } ?>
<?php } ?>
<div id="uploadFiles" class="modal fade" role="dialog" ngf-drop="uploadFiles($files)" ngf-multiple="true">
    <div class="modal-dialog">
        <div class="modal-content <?php if(!isMobile()){ ?>mediumModal<?php } ?>">
            <div class="modal-header">
                <button type="button" class="close" data-dismiss="modal">&times;</button>
                <h4 class="modal-title">File Uploader</h4>
            </div>
            <div class="modal-body">
                <div>
                    <div align="center">
                        <div style="width: 90%; border: 1px dashed #585f69; padding: 20px" class="row clickAble"
                             ng-if="currentFileUploadList.length < 1" href="javascript:;"
                             ngf-max-files="10"
                             ngf-max-total-size="'10GB'"
                             ngf-pattern="'!.exe,!.msi'"
                             ngf-select="uploadFiles($files)" multiple>
                            <div class="col-lg-6" style="border-right: 1px dashed #585f69;">
                                <img src="<?=Url::templatePath('default/images/Drag-and-Drop-128.png');?>" />
                                <br /><br />
                                Drag and drop Files
                            </div>
                            <div class="col-lg-6">
                                <img src="<?=Url::templatePath('default/images/Cloud-Upload-128.png');?>" />
                                <br /><br />
                                Choose Files to Upload
                            </div>
                        </div>
                        <br/>
                    </div>
                    <div style="padding: 10px;" ng-if="currentFileUploadList.length > 0">
                        <ul class="currentFileUploadList list-group" ng-repeat="value in currentFileUploadList track by $index" ng-if="value.status != ' - Upload Completed' && value.status != ' - Upload Canceled'">
                            <li class="list-group-item">
                                <i class="fa fa-file-photo-o fa-1x"> {{ value.name | limitTo:30 }} - {{ (value.size/1024) }} KB</i>
                                <span class="uploadStatusText">{{ value.status }}</span>
                                <a class="btn btn-danger btn-small" ng-click="cancelSingleFileUpload($index)">Cancel</a>
                                <span class="percentage pull-right">{{ value.progress }} %</span>
                                <div class="progress" style="height: 10px;margin-top: 8px;margin-bottom: 0px;">
                                    <div class="progress-bar progress-bar-striped active" role="progressbar" aria-valuenow="{{ value.progress }}" aria-valuemin="0" aria-valuemax="100" style="width: {{ value.progress }}%">
                                        <span class="sr-only">{{ value.progress }} % Complete</span>
                                    </div>
                                </div>
                            </li>
                        </ul>
                    </div>
                    <?php if(!empty(CUSTOM_UPLOAD_MESSAGE) || CUSTOM_UPLOAD_MESSAGE != ''){ ?>
                        <div>
                            <?php $messages = explode('|', CUSTOM_UPLOAD_MESSAGE); ?>
                            <ul class="list-inline">
                                <?php foreach($messages as $message){ ?>
                                    <li class="list"><i class="fa fa-dot-circle-o danger"></i> <?=$message;?></li>
                                <?php } ?>
                                <?php if(FILE_EXCLUDE_EXTENSIONS){ ?>
                                    <li class="list"><i class="fa fa-dot-circle-o danger"></i> File types <?=FILE_EXCLUDE_EXTENSIONS;?> cannot be uploaded due to security reasons</li>
                                <?php }else if(FILE_INCLUDE_EXTENSIONS){ ?>
                                    <li class="list"><i class="fa fa-dot-circle-o danger"></i> Only File types <?=FILE_INCLUDE_EXTENSIONS;?> can be uploaded due to security reasons</li>
                                <?php } ?>
                            </ul>
                        </div>
                    <?php }?>
                    <span class="pull-right">
<!--                        <a ng-if="currentFileUploadList.length < 1" href="javascript:;" class="btn btn-default"-->
<!--                           ngf-max-files="10"-->
<!--                           ngf-max-total-size="'10GB'"-->
<!--                           ngf-pattern="'!.exe,!.msi'"-->
<!--                           ngf-select="uploadFiles($files)" multiple>-->
<!--                            <i class="share-icon fa fa-upload"> Choose Files</i>-->
<!--                        </a>-->
                        <button type="button" class="btn btn-default" data-dismiss="modal">Close</button>
                        <button type="button" id="UploadCancelBtn" class="btn btn-info cancelBtn" ng-if="currentFileUploadList.length > 0" ng-click="cancelUploadAll()">Cancel Uploads</button>
                    </span>
                    <br/><br/>
                </div>
            </div>
        </div>
    </div>
</div>
<div id="createMiniCloud" class="modal fade" role="dialog">
    <div class="modal-dialog">
        <div class="modal-content <?php if(!isMobile()){ ?>mediumModal<?php } ?>">
            <div class="modal-header">
                <button type="button" class="close" data-dismiss="modal">&times;</button>
                <h4 class="modal-title">Create a Mini Cloud</h4>
            </div>
            <div class="modal-body">
                <div>
                    <form class="row form-inline" ng-submit="createMiniCloud(miniCloudName)">
                        <div class="form-group col-lg-10">
                            <label class="sr-only" for="miniCloudName">Enter a Mini Cloud Name</label>
                            <input type="text" style="width: 100%;" ng-model="miniCloudName" class="form-control" name="miniCloudName" id="miniCloudName" placeholder="Enter a Mini Cloud Name">
                        </div>

                        <button type="submit" class="btn btn-default">Create</button>
                        <button type="button" class="btn btn-default" data-dismiss="modal">Close</button>
                    </form>
                </div>
                <span class="createMiniCloudError"></span>
            </div>
        </div>
    </div>
</div>
<div id="createFolder" class="modal fade" role="dialog">
    <div class="modal-dialog">
        <div class="modal-content <?php if(!isMobile()){ ?>mediumModal<?php } ?>">
            <div class="modal-header">
                <button type="button" class="close" data-dismiss="modal">&times;</button>
                <h4 class="modal-title">Create a folder</h4>
            </div>
            <div class="modal-body">
                <div>
                    <form class="form-inline row" ng-submit="createFolder(folderName)">
                        <div class="form-group col-lg-10">
                            <label class="sr-only" for="folderName">Enter a Folder Name</label>
                            <input type="text" style="width: 100%;" ng-model="folderName" class="form-control" name="folderName" id="folderName" placeholder="Enter a Folder Name">
                        </div>

                        <button type="submit" class="btn btn-default">Create</button>
                        <button type="button" class="btn btn-default" data-dismiss="modal">Close</button>
                    </form>
                </div>
                <br/>
                <p>
                    <span ng-if="crumbString.length > 0">Note: Folder will be created inside "{{ crumbString }}" folder</span>
                    <span ng-if="crumbString.length == null">Note: Folder will be created in "{{ crumbString }}" folder</span>
                    <span class="createFolderError"></span>
                </p>
            </div>
        </div>
    </div>
</div>
<div id="uploadFilesNew" class="modal fade" role="dialog" data-backdrop="static" data-keyboard="false">
    <div class="modal-dialog">
        <div class="modal-content <?php if(!isMobile()){ ?>mediumModal<?php } ?>">
            <div class="modal-header">
                <h4 class="modal-title">File Uploader</h4>
            </div>
            <div class="modal-body">
                <div>
                    <div align="center">    
<!-- yyyyyyyyyyy-->
<ul class="nav nav-tabs" style="font-size: medium;font-weight: 600;">
    <li class="active" ><a data-toggle="tab" href="#menu1">Choose files to upload</a></li>
  </ul>
<div class="tab-content">
    <div id="menu1" class="tab-pane fade in active">
      <p id="statusForFolder" style="display:none;text-align: left;margin-left: 20px;margin-bottom: 10px;">Files Uploaded: <span id="currentCountForFolder"></span> out of <span id="totalCountForFolder"></span></p>
      <div id="filelist">Your browser doesn't have Flash, Silverlight or HTML5 support.</div>
<br />
<center><span id="crawlingSpinner" style="display:none;"><i class="fa fa-spinner fa-4x fa-pulse fa-fw"></i></span></center>        
<a id="pickfiles" href="javascript:;" >
    <div style="font-weight : 600!important;">
                                <img src="<?=Url::templatePath('default/images/Cloud-Upload-128.png');?>" />
                                <br /><br />
                                Choose Files to Upload
                            </div></a>
      <div id="debug">No runtime found, your browser doesn't support HTML5 drag &amp; drop upload.</div>
    </div>
    </div>
<br />
<!--yyyyyyyyyy -->
                    <span class="pull-right">
                        <button id="closeNewUpload" type="button" class="btn btn-default" data-dismiss="modal">Cancel</button>
                    </span>
                    <br/><br/>
</div>
            </div>
        </div>
    </div>
</div>
</div>
<?php } ?>

==> patch-2.5.3.19.zip: app/templates/default/partials/createButton.php <==
<?php use Helpers\Url; use Helpers\Auth;?>
<?php if(Auth::checkCloudPermission('sync')){ ?>
<?php if(Auth::checkUserPermission('admin')) {?>
<?php if($data['createMiniCloud'] == 'true' || $data['fileUpload'] == 'true' || $data['createFolder'] == 'true') {?>
<div class="share pull-right">
    <button class="share-toggle-button universalCreate">
        <i class="createButton share-icon fa fa-plus"></i>
    </button>
    <?php if($data['createMiniCloud'] == 'true' || $data['fileUpload'] == 'true' || $data['createFolder'] == 'true') {?>
    <ul class="share-items">
        <?php if(Auth::checkUserPermission('admin')) {?>
            <?php if($data['createMiniCloud'] == 'true') { ?>
            <li title="Create a MiniCloud"  id="createAminicloud" class="share-item">
                <a href="" class="share-button" data-toggle="modal" data-target="#createMiniCloud">
                    <i class="share-icon fa fa-cloud"></i>
                </a>
            </li>
            <?php } ?>
        <?php } ?>
        <?php if($data['active'] == 'sync'){ ?>
            <?php if($data['fileUpload'] == 'true') { ?>
                <?php if(!isMobile()){ ?>
                <li title="New Upload" id="newUpload" class="share-item">
                    <a href="" class="share-button" data-toggle="modal" data-target="#uploadFilesNew">
                        <i class="share-icon fa fa-upload"></i>
                    </a>
                </li>
                <?php } ?>
            <?php } ?>
        <?php } ?>
        <?php if($data['createFolder'] == 'true') { ?>
        <li title="Create a Folder" id="createAFolder" class="share-item">
            <a href="" class="share-button" data-toggle="modal" data-target="#createFolder">
                <i class="share-icon fa fa-folder-open"></i>
            </a>
        </li>
        <?php } ?>
    </ul>
    <?php } ?>
</div>
<?php } ?>
<?php }else {?>
<?php if($data['fileUpload'] == 'true' || $data['createFolder'] == 'true') {?>
<div class="share pull-right">
    <button class="share-toggle-button universalCreate">
        <i class="createButton share-icon fa fa-plus"></i>
    </button>
    <?php if($data['fileUpload'] == 'true' || $data['createFolder'] == 'true') {?>
    <ul class="share-items">
        <?php if($data['active'] == 'sync'){ ?>
            <?php if($data['fileUpload'] == 'true') { ?>
                <?php if(!isMobile()){ ?>
                <li title="New Upload" id="newUpload" class="share-item">
                    <a href="" class="share-button" data-toggle="modal" data-target="#uploadFilesNew">
                        <i class="share-icon fa fa-upload"></i>
                    </a>
                </li>
                <?php } ?>
            <?php } ?>
        <?php } ?>
        <?php if($data['createFolder'] == 'true') { ?>
        <li title="Create a Folder" id="createAFolder" class="share-item">
            <a href="" class="share-button" data-toggle="modal" data-target="#createFolder">
                <i class="share-icon fa fa-folder-open"></i>
            </a>
        </li>
        <?php } ?>
    </ul>
    <?php } ?>
</div>
<?php } ?>
<?php } ?>
<div id="uploadFiles" class="modal fade" role="dialog" ngf-drop="uploadFiles($files)" ngf-multiple="true">
    <div class="modal-dialog">
        <div class="modal-content <?php if(!isMobile()){ ?>mediumModal<?php } ?>">
            <div class="modal-header">
                <button type="button" class="close" data-dismiss="modal">&times;</button>
                <h4 class="modal-title">File Uploader</h4>
            </div>
            <div class="modal-body">
                <div>
                    <div align="center">
                        <div style="width: 90%; border: 1px dashed #585f69; padding: 20px" class="row clickAble"
                             ng-if="currentFileUploadList.length < 1" href="javascript:;"
                             ngf-max-files="10"
                             ngf-max-total-size="'10GB'"
                             ngf-pattern="'!.exe,!.msi'"
                             ngf-select="uploadFiles($files)" multiple>
                            <div class="col-lg-6" style="border-right: 1px dashed #585f69;">
                                <img src="<?=Url::templatePath('default/images/Drag-and-Drop-128.png');?>" />
                                <br /><br />
                                Drag and drop Files
                            </div>
                            <div class="col-lg-6">
                                <img src="<?=Url::templatePath('default/images/Cloud-Upload-128.png');?>" />
                                <br /><br />
                                Choose Files to Upload
                            </div>
                        </div>
                        <br/>
                    </div>
                    <div style="padding: 10px;" ng-if="currentFileUploadList.length > 0">
                        <ul class="currentFileUploadList list-group" ng-repeat="value in currentFileUploadList track by $index" ng-if="value.status != ' - Upload Completed' && value.status != ' - Upload Canceled'">
                            <li class="list-group-item">
                                <i class="fa fa-file-photo-o fa-1x"> {{ value.name | limitTo:30 }} - {{ (value.size/1024) }} KB</i>
                                <span class="uploadStatusText">{{ value.status }}</span>
                                <a class="btn btn-danger btn-small" ng-click="cancelSingleFileUpload($index)">Cancel</a>
                                <span class="percentage pull-right">{{ value.progress }} %</span>
                                <div class="progress" style="height: 10px;margin-top: 8px;margin-bottom: 0px;">
                                    <div class="progress-bar progress-bar-striped active" role="progressbar" aria-valuenow="{{ value.progress }}" aria-valuemin="0" aria-valuemax="100" style="width: {{ value.progress }}%">
                                        <span class="sr-only">{{ value.progress }} % Complete</span>
                                    </div>
                                </div>
                            </li>
                        </ul>
                    </div>
                    <?php if(!empty(CUSTOM_UPLOAD_MESSAGE) || CUSTOM_UPLOAD_MESSAGE != ''){ ?>
                        <div>
                            <?php $messages = explode('|', CUSTOM_UPLOAD_MESSAGE); ?>
                            <ul class="list-inline">
                                <?php foreach($messages as $message){ ?>
                                    <li class="list"><i class="fa fa-dot-circle-o danger"></i> <?=$message;?></li>
                                <?php } ?>
                                <?php if(FILE_EXCLUDE_EXTENSIONS){ ?>
                                    <li class="list"><i class="fa fa-dot-circle-o danger"></i> File types <?=FILE_EXCLUDE_EXTENSIONS;?> cannot be uploaded due to security reasons</li>
                                <?php }else if(FILE_INCLUDE_EXTENSIONS){ ?>
                                    <li class="list"><i class="fa fa-dot-circle-o danger"></i> Only File types <?=FILE_INCLUDE_EXTENSIONS;?> can be uploaded due to security reasons</li>
                                <?php } ?>
                            </ul>
                        </div>
                    <?php }?>
                    <span class="pull-right">
<!--                        <a ng-if="currentFileUploadList.length < 1" href="javascript:;" class="btn btn-default"-->
<!--                           ngf-max-files="10"-->
<!--                           ngf-max-total-size="'10GB'"-->
<!--                           ngf-pattern="'!.exe,!.msi'"-->
<!--                           ngf-select="uploadFiles($files)" multiple>-->
<!--                            <i class="share-icon fa fa-upload"> Choose Files</i>-->
<!--                        </a>-->
                        <button type="button" class="btn btn-default" data-dismiss="modal">Close</button>
                        <button type="button" id="UploadCancelBtn" class="btn btn-info cancelBtn" ng-if="currentFileUploadList.length > 0" ng-click="cancelUploadAll()">Cancel Uploads</button>
                    </span>
                    <br/><br/>
                </div>
            </div>
        </div>
    </div>
</div>
<div id="createMiniCloud" class="modal fade" role="dialog">
    <div class="modal-dialog">
        <div class="modal-content <?php if(!isMobile()){ ?>mediumModal<?php } ?>">
            <div class="modal-header">
                <button type="button" class="close" data-dismiss="modal">&times;</button>
                <h4 class="modal-title">Create a Mini Cloud</h4>
            </div>
            <div class="modal-body">
                <div>
                    <form class="row form-inline" ng-submit="createMiniCloud(miniCloudName)">
                        <div class="form-group col-lg-10">
                            <label class="sr-only" for="miniCloudName">Enter a Mini Cloud Name</label>
                            <input type="text" style="width: 100%;" ng-model="miniCloudName" class="form-control" name="miniCloudName" id="miniCloudName" placeholder="Enter a Mini Cloud Name">
                        </div>

                        <button type="submit" class="btn btn-default">Create</button>
                        <button type="button" class="btn btn-default" data-dismiss="modal">Close</button>
                    </form>
                </div>
                <span class="createMiniCloudError"></span>
            </div>
        </div>
    </div>
</div>
<div id="createFolder" class="modal fade" role="dialog">
    <div class="modal-dialog">
        <div class="modal-content <?php if(!isMobile()){ ?>mediumModal<?php } ?>">
            <div class="modal-header">
                <button type="button" class="close" data-dismiss="modal">&times;</button>
                <h4 class="modal-title">Create a folder</h4>
            </div>
            <div class="modal-body">
                <div>
                    <form class="form-inline row" ng-submit="createFolder(folderName)">
                        <div class="form-group col-lg-10">
                            <label class="sr-only" for="folderName">Enter a Folder Name</label>
                            <input type="text" style="width: 100%;" ng-model="folderName" class="form-control" name="folderName" id="folderName" placeholder="Enter a Folder Name">
                        </div>

                        <button type="submit" class="btn btn-default">Create</button>
                        <button type="button" class="btn btn-default" data-dismiss="modal">Close</button>
                    </form>
                </div>
                <br/>
                <p>
                    <span ng-if="crumbString.length > 0">Note: Folder will be created inside "{{ crumbString }}" folder</span>
                    <span ng-if="crumbString.length == null">Note: Folder will be created in "{{ crumbString }}" folder</span>
                    <span class="createFolderError"></span>
                </p>
            </div>
        </div>
    </div>
</div>
<div id="uploadFilesNew" class="modal fade" role="dialog" data-backdrop="static" data-keyboard="false">
    <div class="modal-dialog">
        <div class="modal-content <?php if(!isMobile()){ ?>mediumModal<?php } ?>">
            <div class="modal-header">
                <h4 class="modal-title">File Uploader</h4>
            </div>
            <div class="modal-body">
                <div>
                    <div align="center">    
<!-- yyyyyyyyyyy-->
<ul class="nav nav-tabs" style="font-size: medium;font-weight: 600;">
    <li class="active" ><a data-toggle="tab" href="#menu1">Choose files to upload</a></li>
  </ul>
<div class="tab-content">
    <div id="menu1" class="tab-pane fade in active">
      <p id="statusForFolder" style="display:none;text-align: left;margin-left: 20px;margin-bottom: 10px;">Files Uploaded: <span id="currentCountForFolder"></span> out of <span id="totalCountForFolder"></span></p>
      <div id="filelist">Your browser doesn't have Flash, Silverlight or HTML5 support.</div>
<br />
<center><span id="crawlingSpinner" style="display:none;"><i class="fa fa-spinner fa-4x fa-pulse fa-fw"></i></span></center>        
<a id="pickfiles" href="javascript:;" >
    <div style="font-weight : 600!important;">
                                <img src="<?=Url::templatePath('default/images/Cloud-Upload-128.png');?>" />
                                <br /><br />
                                Choose Files to Upload
    </div>
</a>
      <div id="debug">No runtime found, your browser doesn't support HTML5 drag &amp; drop upload.</div>
      <div class="bs-callout bs-callout-primary" style="padding-top: 10px; padding-bottom: 1px;">
        <p>This operation could take some time. Please be patient while the upload is in progress, and don’t close this tab. If you wish to, you can duplicate this tab and continue to perform other actions.</p>
      </div>
    </div>
    </div>
<br />
<!--yyyyyyyyyy-->
                    <span class="pull-right">
                        <button id="closeNewUpload" type="button" class="btn btn-default" data-dismiss="modal">Cancel</button>
                    </span>
                    <br/><br/>
</div>
            </div>
        </div>
    </div>
</div>
</div>
<?php } ?>
